All of lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH] hwmon: (k10temp) add support for AMD Family 12h/14h CPUs
@ 2011-02-17  8:22 ` Clemens Ladisch
  0 siblings, 0 replies; 20+ messages in thread
From: Clemens Ladisch @ 2011-02-17  8:22 UTC (permalink / raw)
  To: Jean Delvare, Guenter Roeck; +Cc: lm-sensors, linux-kernel

Add the PCI ID to support the internal temperature sensor of the
AMD "Llano" and "Brazos" processor families.

Signed-off-by: Clemens Ladisch <clemens@ladisch.de>
---
 Documentation/hwmon/k10temp |    8 +++++++-
 drivers/hwmon/Kconfig       |    6 +++---
 drivers/hwmon/k10temp.c     |    5 +++--
 3 files changed, 13 insertions(+), 6 deletions(-)

--- a/Documentation/hwmon/k10temp
+++ b/Documentation/hwmon/k10temp
@@ -9,6 +9,8 @@ Supported chips:
   Socket S1G3: Athlon II, Sempron, Turion II
 * AMD Family 11h processors:
   Socket S1G2: Athlon (X2), Sempron (X2), Turion X2 (Ultra)
+* AMD Family 12h processors: "Llano"
+* AMD Family 14h processors: "Brazos" (C/E/G-Series)
 
   Prefix: 'k10temp'
   Addresses scanned: PCI space
@@ -17,10 +19,14 @@ Supported chips:
     http://support.amd.com/us/Processor_TechDocs/31116.pdf
   BIOS and Kernel Developer's Guide (BKDG) for AMD Family 11h Processors:
     http://support.amd.com/us/Processor_TechDocs/41256.pdf
+  BIOS and Kernel Developer's Guide (BKDG) for AMD Family 14h Models 00h-0Fh Processors:
+    http://support.amd.com/us/Processor_TechDocs/43170.pdf
   Revision Guide for AMD Family 10h Processors:
     http://support.amd.com/us/Processor_TechDocs/41322.pdf
   Revision Guide for AMD Family 11h Processors:
     http://support.amd.com/us/Processor_TechDocs/41788.pdf
+  Revision Guide for AMD Family 14h Models 00h-0Fh Processors:
+    http://support.amd.com/us/Processor_TechDocs/47534.pdf
   AMD Family 11h Processor Power and Thermal Data Sheet for Notebooks:
     http://support.amd.com/us/Processor_TechDocs/43373.pdf
   AMD Family 10h Server and Workstation Processor Power and Thermal Data Sheet:
@@ -34,7 +40,7 @@ Description
 -----------
 
 This driver permits reading of the internal temperature sensor of AMD
-Family 10h and 11h processors.
+Family 10h/11h/12h/14h processors.
 
 All these processors have a sensor, but on those for Socket F or AM2+,
 the sensor may return inconsistent values (erratum 319).  The driver
--- a/drivers/hwmon/Kconfig
+++ b/drivers/hwmon/Kconfig
@@ -238,13 +238,13 @@ config SENSORS_K8TEMP
 	  will be called k8temp.
 
 config SENSORS_K10TEMP
-	tristate "AMD Phenom/Sempron/Turion/Opteron temperature sensor"
+	tristate "AMD Family 10h/11h/12h/14h temperature sensor"
 	depends on X86 && PCI
 	help
 	  If you say yes here you get support for the temperature
 	  sensor(s) inside your CPU. Supported are later revisions of
-	  the AMD Family 10h and all revisions of the AMD Family 11h
-	  microarchitectures.
+	  the AMD Family 10h and all revisions of the AMD Family 11h,
+	  12h (Llano), and 14h (Brazos) microarchitectures.
 
 	  This driver can also be built as a module.  If so, the module
 	  will be called k10temp.
--- a/Documentation/hwmon/k10temp
+++ b/Documentation/hwmon/k10temp
@@ -9,6 +9,8 @@ Supported chips:
   Socket S1G3: Athlon II, Sempron, Turion II
 * AMD Family 11h processors:
   Socket S1G2: Athlon (X2), Sempron (X2), Turion X2 (Ultra)
+* AMD Family 12h processors: "Llano"
+* AMD Family 14h processors: "Brazos" (C/E/G-Series)
 
   Prefix: 'k10temp'
   Addresses scanned: PCI space
@@ -17,10 +19,14 @@ Supported chips:
     http://support.amd.com/us/Processor_TechDocs/31116.pdf
   BIOS and Kernel Developer's Guide (BKDG) for AMD Family 11h Processors:
     http://support.amd.com/us/Processor_TechDocs/41256.pdf
+  BIOS and Kernel Developer's Guide (BKDG) for AMD Family 14h Models 00h-0Fh Processors:
+    http://support.amd.com/us/Processor_TechDocs/43170.pdf
   Revision Guide for AMD Family 10h Processors:
     http://support.amd.com/us/Processor_TechDocs/41322.pdf
   Revision Guide for AMD Family 11h Processors:
     http://support.amd.com/us/Processor_TechDocs/41788.pdf
+  Revision Guide for AMD Family 14h Models 00h-0Fh Processors:
+    http://support.amd.com/us/Processor_TechDocs/47534.pdf
   AMD Family 11h Processor Power and Thermal Data Sheet for Notebooks:
     http://support.amd.com/us/Processor_TechDocs/43373.pdf
   AMD Family 10h Server and Workstation Processor Power and Thermal Data Sheet:
@@ -34,7 +40,7 @@ Description
 -----------
 
 This driver permits reading of the internal temperature sensor of AMD
-Family 10h and 11h processors.
+Family 10h/11h/12h/14h processors.
 
 All these processors have a sensor, but on those for Socket F or AM2+,
 the sensor may return inconsistent values (erratum 319).  The driver
--- a/drivers/hwmon/Kconfig
+++ b/drivers/hwmon/Kconfig
@@ -238,13 +238,13 @@ config SENSORS_K8TEMP
 	  will be called k8temp.
 
 config SENSORS_K10TEMP
-	tristate "AMD Phenom/Sempron/Turion/Opteron temperature sensor"
+	tristate "AMD Family 10h/11h/12h/14h temperature sensor"
 	depends on X86 && PCI
 	help
 	  If you say yes here you get support for the temperature
 	  sensor(s) inside your CPU. Supported are later revisions of
-	  the AMD Family 10h and all revisions of the AMD Family 11h
-	  microarchitectures.
+	  the AMD Family 10h and all revisions of the AMD Family 11h,
+	  12h (Llano), and 14h (Brazos) microarchitectures.
 
 	  This driver can also be built as a module.  If so, the module
 	  will be called k10temp.
-- 
Jean Delvare

^ permalink raw reply	[flat|nested] 20+ messages in thread

* Re: [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD
@ 2011-02-17 18:08     ` Jean Delvare
  0 siblings, 0 replies; 20+ messages in thread
From: Jean Delvare @ 2011-02-17 18:08 UTC (permalink / raw)
  To: Guenter Roeck; +Cc: Clemens Ladisch, lm-sensors, linux-kernel

On Thu, 17 Feb 2011 09:26:39 -0800, Guenter Roeck wrote:
> On Thu, Feb 17, 2011 at 03:22:40AM -0500, Clemens Ladisch wrote:
> > Add the PCI ID to support the internal temperature sensor of the
> > AMD "Llano" and "Brazos" processor families.
> > 
> > Signed-off-by: Clemens Ladisch <clemens@ladisch.de>
> 
> Applied, thanks.
> 
> Since it meets the requirements for a stable patch, I applied it to the
> patch list for 2.6.38 and added Cc: stable@kernel.org.

Can we have a sensors-detect patch too?

Thanks,
-- 
Jean Delvare

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 20+ messages in thread

* Re: [PATCH] hwmon: (k10temp) add support for AMD Family 12h/14h CPUs
  2011-02-17 18:08     ` [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD Jean Delvare
@ 2011-02-17 18:39       ` Guenter Roeck
  -1 siblings, 0 replies; 20+ messages in thread
From: Guenter Roeck @ 2011-02-17 18:39 UTC (permalink / raw)
  To: Jean Delvare; +Cc: Clemens Ladisch, lm-sensors, linux-kernel

On Thu, Feb 17, 2011 at 01:08:38PM -0500, Jean Delvare wrote:
> On Thu, 17 Feb 2011 09:26:39 -0800, Guenter Roeck wrote:
> > On Thu, Feb 17, 2011 at 03:22:40AM -0500, Clemens Ladisch wrote:
> > > Add the PCI ID to support the internal temperature sensor of the
> > > AMD "Llano" and "Brazos" processor families.
> > > 
> > > Signed-off-by: Clemens Ladisch <clemens@ladisch.de>
> > 
> > Applied, thanks.
> > 
> > Since it meets the requirements for a stable patch, I applied it to the
> > patch list for 2.6.38 and added Cc: stable@kernel.org.
> 
> Can we have a sensors-detect patch too?
> 
Prepared that, but I am getting the following from the ddr3 patch.

prog/detect/sensors-detect
Useless use of private variable in void context at prog/detect/sensors-detect line 5287.

Code is
	} elsif ($device_type => 9 && $device_type <= 11) {

Should that be 
	} elsif ($device_type >= 9 && $device_type <= 11) {
instead ?

Odd, I didn't notice that before when I tried the ddr3 patch.

Guenter

^ permalink raw reply	[flat|nested] 20+ messages in thread

* Re: [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD
@ 2011-02-17 18:39       ` Guenter Roeck
  0 siblings, 0 replies; 20+ messages in thread
From: Guenter Roeck @ 2011-02-17 18:39 UTC (permalink / raw)
  To: Jean Delvare; +Cc: Clemens Ladisch, lm-sensors, linux-kernel

On Thu, Feb 17, 2011 at 01:08:38PM -0500, Jean Delvare wrote:
> On Thu, 17 Feb 2011 09:26:39 -0800, Guenter Roeck wrote:
> > On Thu, Feb 17, 2011 at 03:22:40AM -0500, Clemens Ladisch wrote:
> > > Add the PCI ID to support the internal temperature sensor of the
> > > AMD "Llano" and "Brazos" processor families.
> > > 
> > > Signed-off-by: Clemens Ladisch <clemens@ladisch.de>
> > 
> > Applied, thanks.
> > 
> > Since it meets the requirements for a stable patch, I applied it to the
> > patch list for 2.6.38 and added Cc: stable@kernel.org.
> 
> Can we have a sensors-detect patch too?
> 
Prepared that, but I am getting the following from the ddr3 patch.

prog/detect/sensors-detect
Useless use of private variable in void context at prog/detect/sensors-detect line 5287.

Code is
	} elsif ($device_type => 9 && $device_type <= 11) {

Should that be 
	} elsif ($device_type >= 9 && $device_type <= 11) {
instead ?

Odd, I didn't notice that before when I tried the ddr3 patch.

Guenter

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 20+ messages in thread

* Re: [PATCH] hwmon: (k10temp) add support for AMD Family 12h/14h  CPUs
  2011-02-17 18:39       ` [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD Guenter Roeck
@ 2011-02-17 19:23         ` Jean Delvare
  -1 siblings, 0 replies; 20+ messages in thread
From: Jean Delvare @ 2011-02-17 19:23 UTC (permalink / raw)
  To: Guenter Roeck; +Cc: Clemens Ladisch, lm-sensors, linux-kernel

On Thu, 17 Feb 2011 10:39:34 -0800, Guenter Roeck wrote:
> On Thu, Feb 17, 2011 at 01:08:38PM -0500, Jean Delvare wrote:
> > On Thu, 17 Feb 2011 09:26:39 -0800, Guenter Roeck wrote:
> > > On Thu, Feb 17, 2011 at 03:22:40AM -0500, Clemens Ladisch wrote:
> > > > Add the PCI ID to support the internal temperature sensor of the
> > > > AMD "Llano" and "Brazos" processor families.
> > > > 
> > > > Signed-off-by: Clemens Ladisch <clemens@ladisch.de>
> > > 
> > > Applied, thanks.
> > > 
> > > Since it meets the requirements for a stable patch, I applied it to the
> > > patch list for 2.6.38 and added Cc: stable@kernel.org.
> > 
> > Can we have a sensors-detect patch too?
> > 
> Prepared that, but I am getting the following from the ddr3 patch.
> 
> prog/detect/sensors-detect
> Useless use of private variable in void context at prog/detect/sensors-detect line 5287.
> 
> Code is
> 	} elsif ($device_type => 9 && $device_type <= 11) {
> 
> Should that be 
> 	} elsif ($device_type >= 9 && $device_type <= 11) {
> instead ?

Yes, you're totally right.

> Odd, I didn't notice that before when I tried the ddr3 patch.

This is the part I modified from Clemens' original patch. What's really
odd is that I didn't notice the warning on my end. I see it now...
Sorry, I've just fixed it.

-- 
Jean Delvare

^ permalink raw reply	[flat|nested] 20+ messages in thread

* Re: [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD
@ 2011-02-17 19:23         ` Jean Delvare
  0 siblings, 0 replies; 20+ messages in thread
From: Jean Delvare @ 2011-02-17 19:23 UTC (permalink / raw)
  To: Guenter Roeck; +Cc: Clemens Ladisch, lm-sensors, linux-kernel

On Thu, 17 Feb 2011 10:39:34 -0800, Guenter Roeck wrote:
> On Thu, Feb 17, 2011 at 01:08:38PM -0500, Jean Delvare wrote:
> > On Thu, 17 Feb 2011 09:26:39 -0800, Guenter Roeck wrote:
> > > On Thu, Feb 17, 2011 at 03:22:40AM -0500, Clemens Ladisch wrote:
> > > > Add the PCI ID to support the internal temperature sensor of the
> > > > AMD "Llano" and "Brazos" processor families.
> > > > 
> > > > Signed-off-by: Clemens Ladisch <clemens@ladisch.de>
> > > 
> > > Applied, thanks.
> > > 
> > > Since it meets the requirements for a stable patch, I applied it to the
> > > patch list for 2.6.38 and added Cc: stable@kernel.org.
> > 
> > Can we have a sensors-detect patch too?
> > 
> Prepared that, but I am getting the following from the ddr3 patch.
> 
> prog/detect/sensors-detect
> Useless use of private variable in void context at prog/detect/sensors-detect line 5287.
> 
> Code is
> 	} elsif ($device_type => 9 && $device_type <= 11) {
> 
> Should that be 
> 	} elsif ($device_type >= 9 && $device_type <= 11) {
> instead ?

Yes, you're totally right.

> Odd, I didn't notice that before when I tried the ddr3 patch.

This is the part I modified from Clemens' original patch. What's really
odd is that I didn't notice the warning on my end. I see it now...
Sorry, I've just fixed it.

-- 
Jean Delvare

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 20+ messages in thread

* [PATCH] hwmon: (k10temp) Add support for Fam16h (Kabini)
  2011-02-17  8:22 ` [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD Family Clemens Ladisch
@ 2013-08-23 17:38 ` Wei Hu
  -1 siblings, 0 replies; 20+ messages in thread
From: Wei Hu @ 2013-08-23 17:38 UTC (permalink / raw)
  To: Clemens Ladisch, lm-sensors, linux-kernel; +Cc: Wei Hu

The temperature reporting interface stays the same, so we just
add the PCI-ID to the list.

Verified on AMD Olive Hill.
---
 Documentation/hwmon/k10temp |    1 +
 drivers/hwmon/Kconfig       |    4 ++--
 drivers/hwmon/k10temp.c     |    3 ++-
 3 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/Documentation/hwmon/k10temp b/Documentation/hwmon/k10temp
index 90956b6..4dfdc8f 100644
--- a/Documentation/hwmon/k10temp
+++ b/Documentation/hwmon/k10temp
@@ -12,6 +12,7 @@ Supported chips:
 * AMD Family 12h processors: "Llano" (E2/A4/A6/A8-Series)
 * AMD Family 14h processors: "Brazos" (C/E/G/Z-Series)
 * AMD Family 15h processors: "Bulldozer" (FX-Series), "Trinity"
+* AMD Family 16h processors: "Kabini"
 
   Prefix: 'k10temp'
   Addresses scanned: PCI space
diff --git a/drivers/hwmon/Kconfig b/drivers/hwmon/Kconfig
index e989f7f..1e27838 100644
--- a/drivers/hwmon/Kconfig
+++ b/drivers/hwmon/Kconfig
@@ -296,8 +296,8 @@ config SENSORS_K10TEMP
 	  If you say yes here you get support for the temperature
 	  sensor(s) inside your CPU. Supported are later revisions of
 	  the AMD Family 10h and all revisions of the AMD Family 11h,
-	  12h (Llano), 14h (Brazos) and 15h (Bulldozer/Trinity)
-	  microarchitectures.
+	  12h (Llano), 14h (Brazos), 15h (Bulldozer/Trinity) and
+	  16h (Kabini) microarchitectures.
 
 	  This driver can also be built as a module.  If so, the module
 	  will be called k10temp.
-- 
1.7.4.4


^ permalink raw reply related	[flat|nested] 20+ messages in thread

* [lm-sensors] [PATCH] hwmon: (k10temp) Add support for Fam16h (Kabini)
@ 2013-08-23 17:38 ` Wei Hu
  0 siblings, 0 replies; 20+ messages in thread
From: Wei Hu @ 2013-08-23 17:38 UTC (permalink / raw)
  To: Clemens Ladisch, lm-sensors, linux-kernel; +Cc: Wei Hu

The temperature reporting interface stays the same, so we just
add the PCI-ID to the list.

Verified on AMD Olive Hill.
---
 Documentation/hwmon/k10temp |    1 +
 drivers/hwmon/Kconfig       |    4 ++--
 drivers/hwmon/k10temp.c     |    3 ++-
 3 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/Documentation/hwmon/k10temp b/Documentation/hwmon/k10temp
index 90956b6..4dfdc8f 100644
--- a/Documentation/hwmon/k10temp
+++ b/Documentation/hwmon/k10temp
@@ -12,6 +12,7 @@ Supported chips:
 * AMD Family 12h processors: "Llano" (E2/A4/A6/A8-Series)
 * AMD Family 14h processors: "Brazos" (C/E/G/Z-Series)
 * AMD Family 15h processors: "Bulldozer" (FX-Series), "Trinity"
+* AMD Family 16h processors: "Kabini"
 
   Prefix: 'k10temp'
   Addresses scanned: PCI space
diff --git a/drivers/hwmon/Kconfig b/drivers/hwmon/Kconfig
index e989f7f..1e27838 100644
--- a/drivers/hwmon/Kconfig
+++ b/drivers/hwmon/Kconfig
@@ -296,8 +296,8 @@ config SENSORS_K10TEMP
 	  If you say yes here you get support for the temperature
 	  sensor(s) inside your CPU. Supported are later revisions of
 	  the AMD Family 10h and all revisions of the AMD Family 11h,
-	  12h (Llano), 14h (Brazos) and 15h (Bulldozer/Trinity)
-	  microarchitectures.
+	  12h (Llano), 14h (Brazos), 15h (Bulldozer/Trinity) and
+	  16h (Kabini) microarchitectures.
 
 	  This driver can also be built as a module.  If so, the module
 	  will be called k10temp.
-- 
1.7.4.4


_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply related	[flat|nested] 20+ messages in thread

* Re: [PATCH] hwmon: (k10temp) Add support for Fam16h (Kabini)
  2013-08-23 17:38 ` [lm-sensors] " Wei Hu
@ 2013-08-23 18:25   ` Clemens Ladisch
  -1 siblings, 0 replies; 20+ messages in thread
From: Clemens Ladisch @ 2013-08-23 18:25 UTC (permalink / raw)
  To: lm-sensors; +Cc: Wei Hu, linux-kernel

Wei Hu wrote:
> The temperature reporting interface stays the same, so we just
> add the PCI-ID to the list.
>
> Verified on AMD Olive Hill.
> ---
>  Documentation/hwmon/k10temp |    1 +
>  drivers/hwmon/Kconfig       |    4 ++--
>  drivers/hwmon/k10temp.c     |    3 ++-
>  3 files changed, 5 insertions(+), 3 deletions(-)

Acked-by: Clemens Ladisch <clemens@ladisch.de>

^ permalink raw reply	[flat|nested] 20+ messages in thread

* Re: [lm-sensors] [PATCH] hwmon: (k10temp) Add support for Fam16h (Kabini)
@ 2013-08-23 18:25   ` Clemens Ladisch
  0 siblings, 0 replies; 20+ messages in thread
From: Clemens Ladisch @ 2013-08-23 18:25 UTC (permalink / raw)
  To: lm-sensors; +Cc: Wei Hu, linux-kernel

Wei Hu wrote:
> The temperature reporting interface stays the same, so we just
> add the PCI-ID to the list.
>
> Verified on AMD Olive Hill.
> ---
>  Documentation/hwmon/k10temp |    1 +
>  drivers/hwmon/Kconfig       |    4 ++--
>  drivers/hwmon/k10temp.c     |    3 ++-
>  3 files changed, 5 insertions(+), 3 deletions(-)

Acked-by: Clemens Ladisch <clemens@ladisch.de>

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 20+ messages in thread

* Re: [lm-sensors] [PATCH] hwmon: (k10temp) Add support for Fam16h (Kabini)
  2013-08-23 17:38 ` [lm-sensors] " Wei Hu
@ 2013-08-23 19:58   ` Guenter Roeck
  -1 siblings, 0 replies; 20+ messages in thread
From: Guenter Roeck @ 2013-08-23 19:58 UTC (permalink / raw)
  To: Wei Hu; +Cc: Clemens Ladisch, lm-sensors, linux-kernel

On Fri, Aug 23, 2013 at 10:38:18AM -0700, Wei Hu wrote:
> The temperature reporting interface stays the same, so we just
> add the PCI-ID to the list.
> 
> Verified on AMD Olive Hill.

The Signed-off-by: statement is missing. I can not apply the patch without it.

Guenter

> ---
>  Documentation/hwmon/k10temp |    1 +
>  drivers/hwmon/Kconfig       |    4 ++--
>  drivers/hwmon/k10temp.c     |    3 ++-
>  3 files changed, 5 insertions(+), 3 deletions(-)
> 
> diff --git a/Documentation/hwmon/k10temp b/Documentation/hwmon/k10temp
> index 90956b6..4dfdc8f 100644
> --- a/Documentation/hwmon/k10temp
> +++ b/Documentation/hwmon/k10temp
> @@ -12,6 +12,7 @@ Supported chips:
>  * AMD Family 12h processors: "Llano" (E2/A4/A6/A8-Series)
>  * AMD Family 14h processors: "Brazos" (C/E/G/Z-Series)
>  * AMD Family 15h processors: "Bulldozer" (FX-Series), "Trinity"
> +* AMD Family 16h processors: "Kabini"
>  
>    Prefix: 'k10temp'
>    Addresses scanned: PCI space
> diff --git a/drivers/hwmon/Kconfig b/drivers/hwmon/Kconfig
> index e989f7f..1e27838 100644
> --- a/drivers/hwmon/Kconfig
> +++ b/drivers/hwmon/Kconfig
> @@ -296,8 +296,8 @@ config SENSORS_K10TEMP
>  	  If you say yes here you get support for the temperature
>  	  sensor(s) inside your CPU. Supported are later revisions of
>  	  the AMD Family 10h and all revisions of the AMD Family 11h,
> -	  12h (Llano), 14h (Brazos) and 15h (Bulldozer/Trinity)
> -	  microarchitectures.
> +	  12h (Llano), 14h (Brazos), 15h (Bulldozer/Trinity) and
> +	  16h (Kabini) microarchitectures.
>  
>  	  This driver can also be built as a module.  If so, the module
>  	  will be called k10temp.
> diff --git a/drivers/hwmon/k10temp.c b/drivers/hwmon/k10temp.c
> index e3b037c..e633856 100644
> --- a/drivers/hwmon/k10temp.c
> +++ b/drivers/hwmon/k10temp.c
> @@ -1,5 +1,5 @@
>  /*
> - * k10temp.c - AMD Family 10h/11h/12h/14h/15h processor hardware monitoring
> + * k10temp.c - AMD Family 10h/11h/12h/14h/15h/16h processor hardware monitoring
>   *
>   * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>
>   *
> @@ -211,6 +211,7 @@ static DEFINE_PCI_DEVICE_TABLE(k10temp_id_table) = {
>  	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_CNB17H_F3) },
>  	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_15H_NB_F3) },
>  	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_15H_M10H_F3) },
> +	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_16H_NB_F3) },
>  	{}
>  };
>  MODULE_DEVICE_TABLE(pci, k10temp_id_table);
> -- 
> 1.7.4.4
> 
> 
> _______________________________________________
> lm-sensors mailing list
> lm-sensors@lm-sensors.org
> http://lists.lm-sensors.org/mailman/listinfo/lm-sensors
> 

^ permalink raw reply	[flat|nested] 20+ messages in thread

* Re: [lm-sensors] [PATCH] hwmon: (k10temp) Add support for Fam16h (Kabini)
@ 2013-08-23 19:58   ` Guenter Roeck
  0 siblings, 0 replies; 20+ messages in thread
From: Guenter Roeck @ 2013-08-23 19:58 UTC (permalink / raw)
  To: Wei Hu; +Cc: Clemens Ladisch, lm-sensors, linux-kernel

On Fri, Aug 23, 2013 at 10:38:18AM -0700, Wei Hu wrote:
> The temperature reporting interface stays the same, so we just
> add the PCI-ID to the list.
> 
> Verified on AMD Olive Hill.

The Signed-off-by: statement is missing. I can not apply the patch without it.

Guenter

> ---
>  Documentation/hwmon/k10temp |    1 +
>  drivers/hwmon/Kconfig       |    4 ++--
>  drivers/hwmon/k10temp.c     |    3 ++-
>  3 files changed, 5 insertions(+), 3 deletions(-)
> 
> diff --git a/Documentation/hwmon/k10temp b/Documentation/hwmon/k10temp
> index 90956b6..4dfdc8f 100644
> --- a/Documentation/hwmon/k10temp
> +++ b/Documentation/hwmon/k10temp
> @@ -12,6 +12,7 @@ Supported chips:
>  * AMD Family 12h processors: "Llano" (E2/A4/A6/A8-Series)
>  * AMD Family 14h processors: "Brazos" (C/E/G/Z-Series)
>  * AMD Family 15h processors: "Bulldozer" (FX-Series), "Trinity"
> +* AMD Family 16h processors: "Kabini"
>  
>    Prefix: 'k10temp'
>    Addresses scanned: PCI space
> diff --git a/drivers/hwmon/Kconfig b/drivers/hwmon/Kconfig
> index e989f7f..1e27838 100644
> --- a/drivers/hwmon/Kconfig
> +++ b/drivers/hwmon/Kconfig
> @@ -296,8 +296,8 @@ config SENSORS_K10TEMP
>  	  If you say yes here you get support for the temperature
>  	  sensor(s) inside your CPU. Supported are later revisions of
>  	  the AMD Family 10h and all revisions of the AMD Family 11h,
> -	  12h (Llano), 14h (Brazos) and 15h (Bulldozer/Trinity)
> -	  microarchitectures.
> +	  12h (Llano), 14h (Brazos), 15h (Bulldozer/Trinity) and
> +	  16h (Kabini) microarchitectures.
>  
>  	  This driver can also be built as a module.  If so, the module
>  	  will be called k10temp.
> diff --git a/drivers/hwmon/k10temp.c b/drivers/hwmon/k10temp.c
> index e3b037c..e633856 100644
> --- a/drivers/hwmon/k10temp.c
> +++ b/drivers/hwmon/k10temp.c
> @@ -1,5 +1,5 @@
>  /*
> - * k10temp.c - AMD Family 10h/11h/12h/14h/15h processor hardware monitoring
> + * k10temp.c - AMD Family 10h/11h/12h/14h/15h/16h processor hardware monitoring
>   *
>   * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>
>   *
> @@ -211,6 +211,7 @@ static DEFINE_PCI_DEVICE_TABLE(k10temp_id_table) = {
>  	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_CNB17H_F3) },
>  	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_15H_NB_F3) },
>  	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_15H_M10H_F3) },
> +	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_16H_NB_F3) },
>  	{}
>  };
>  MODULE_DEVICE_TABLE(pci, k10temp_id_table);
> -- 
> 1.7.4.4
> 
> 
> _______________________________________________
> lm-sensors mailing list
> lm-sensors@lm-sensors.org
> http://lists.lm-sensors.org/mailman/listinfo/lm-sensors
> 

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 20+ messages in thread

* [PATCH] hwmon: (k10temp) Add support for Fam16h (Kabini)
  2013-08-23 19:58   ` Guenter Roeck
@ 2013-08-23 20:14     ` Wei Hu
  -1 siblings, 0 replies; 20+ messages in thread
From: Wei Hu @ 2013-08-23 20:14 UTC (permalink / raw)
  To: Guenter Roeck, Clemens Ladisch, lm-sensors, linux-kernel; +Cc: Wei Hu

The temperature reporting interface stays the same, so we just
add the PCI-ID to the list.

Verified on AMD Olive Hill.

Signed-off-by: Wei Hu <wei@aristanetworks.com>
---
 Documentation/hwmon/k10temp |    1 +
 drivers/hwmon/Kconfig       |    4 ++--
 drivers/hwmon/k10temp.c     |    3 ++-
 3 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/Documentation/hwmon/k10temp b/Documentation/hwmon/k10temp
index 90956b6..4dfdc8f 100644
--- a/Documentation/hwmon/k10temp
+++ b/Documentation/hwmon/k10temp
@@ -12,6 +12,7 @@ Supported chips:
 * AMD Family 12h processors: "Llano" (E2/A4/A6/A8-Series)
 * AMD Family 14h processors: "Brazos" (C/E/G/Z-Series)
 * AMD Family 15h processors: "Bulldozer" (FX-Series), "Trinity"
+* AMD Family 16h processors: "Kabini"
 
   Prefix: 'k10temp'
   Addresses scanned: PCI space
diff --git a/drivers/hwmon/Kconfig b/drivers/hwmon/Kconfig
index e989f7f..1e27838 100644
--- a/drivers/hwmon/Kconfig
+++ b/drivers/hwmon/Kconfig
@@ -296,8 +296,8 @@ config SENSORS_K10TEMP
 	  If you say yes here you get support for the temperature
 	  sensor(s) inside your CPU. Supported are later revisions of
 	  the AMD Family 10h and all revisions of the AMD Family 11h,
-	  12h (Llano), 14h (Brazos) and 15h (Bulldozer/Trinity)
-	  microarchitectures.
+	  12h (Llano), 14h (Brazos), 15h (Bulldozer/Trinity) and
+	  16h (Kabini) microarchitectures.
 
 	  This driver can also be built as a module.  If so, the module
 	  will be called k10temp.
-- 
1.7.4.4


^ permalink raw reply related	[flat|nested] 20+ messages in thread

* [lm-sensors] [PATCH] hwmon: (k10temp) Add support for Fam16h (Kabini)
@ 2013-08-23 20:14     ` Wei Hu
  0 siblings, 0 replies; 20+ messages in thread
From: Wei Hu @ 2013-08-23 20:14 UTC (permalink / raw)
  To: Guenter Roeck, Clemens Ladisch, lm-sensors, linux-kernel; +Cc: Wei Hu

The temperature reporting interface stays the same, so we just
add the PCI-ID to the list.

Verified on AMD Olive Hill.

Signed-off-by: Wei Hu <wei@aristanetworks.com>
---
 Documentation/hwmon/k10temp |    1 +
 drivers/hwmon/Kconfig       |    4 ++--
 drivers/hwmon/k10temp.c     |    3 ++-
 3 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/Documentation/hwmon/k10temp b/Documentation/hwmon/k10temp
index 90956b6..4dfdc8f 100644
--- a/Documentation/hwmon/k10temp
+++ b/Documentation/hwmon/k10temp
@@ -12,6 +12,7 @@ Supported chips:
 * AMD Family 12h processors: "Llano" (E2/A4/A6/A8-Series)
 * AMD Family 14h processors: "Brazos" (C/E/G/Z-Series)
 * AMD Family 15h processors: "Bulldozer" (FX-Series), "Trinity"
+* AMD Family 16h processors: "Kabini"
 
   Prefix: 'k10temp'
   Addresses scanned: PCI space
diff --git a/drivers/hwmon/Kconfig b/drivers/hwmon/Kconfig
index e989f7f..1e27838 100644
--- a/drivers/hwmon/Kconfig
+++ b/drivers/hwmon/Kconfig
@@ -296,8 +296,8 @@ config SENSORS_K10TEMP
 	  If you say yes here you get support for the temperature
 	  sensor(s) inside your CPU. Supported are later revisions of
 	  the AMD Family 10h and all revisions of the AMD Family 11h,
-	  12h (Llano), 14h (Brazos) and 15h (Bulldozer/Trinity)
-	  microarchitectures.
+	  12h (Llano), 14h (Brazos), 15h (Bulldozer/Trinity) and
+	  16h (Kabini) microarchitectures.
 
 	  This driver can also be built as a module.  If so, the module
 	  will be called k10temp.
--- a/drivers/hwmon/k10temp.c
+++ b/drivers/hwmon/k10temp.c
@@ -1,5 +1,5 @@
 /*
  * k10temp.c - AMD Family 10h/11h processor hardware monitoring
  *
  * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>
  *
@@ -25,7 +25,7 @@
 #include <linux/pci.h>
 #include <asm/processor.h>
 
-MODULE_DESCRIPTION("AMD Family 10h/11h CPU core temperature monitor");
+MODULE_DESCRIPTION("AMD Family 10h/11h/12h/14h CPU core temperature monitor");
 MODULE_AUTHOR("Clemens Ladisch <clemens@ladisch.de>");
 MODULE_LICENSE("GPL");
 
@@ -208,6 +208,7 @@ static void __devexit k10temp_remove(str
 static const struct pci_device_id k10temp_id_table[] = {
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_10H_NB_MISC) },
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_11H_NB_MISC) },
+	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_CNB17H_F3) },
 	{}
 };
 MODULE_DEVICE_TABLE(pci, k10temp_id_table);

^ permalink raw reply	[flat|nested] 20+ messages in thread

* [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD Family
@ 2011-02-17  8:22 ` Clemens Ladisch
  0 siblings, 0 replies; 20+ messages in thread
From: Clemens Ladisch @ 2011-02-17  8:22 UTC (permalink / raw)
  To: Jean Delvare, Guenter Roeck; +Cc: lm-sensors, linux-kernel

Add the PCI ID to support the internal temperature sensor of the
AMD "Llano" and "Brazos" processor families.

Signed-off-by: Clemens Ladisch <clemens@ladisch.de>
---
 Documentation/hwmon/k10temp |    8 +++++++-
 drivers/hwmon/Kconfig       |    6 +++---
 drivers/hwmon/k10temp.c     |    5 +++--
@@ -1,5 +1,5 @@
 /*
- * k10temp.c - AMD Family 10h/11h processor hardware monitoring
+ * k10temp.c - AMD Family 10h/11h/12h/14h processor hardware monitoring
  *
  * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>
 3 files changed, 13 insertions(+), 6 deletions(-)

--- a/drivers/hwmon/k10temp.c
+++ b/drivers/hwmon/k10temp.c
@@ -1,5 +1,5 @@
 /*
  * k10temp.c - AMD Family 10h/11h processor hardware monitoring
  *
  * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>
  *
@@ -25,7 +25,7 @@
 #include <linux/pci.h>
 #include <asm/processor.h>
 
-MODULE_DESCRIPTION("AMD Family 10h/11h CPU core temperature monitor");
+MODULE_DESCRIPTION("AMD Family 10h/11h/12h/14h CPU core temperature monitor");
 MODULE_AUTHOR("Clemens Ladisch <clemens@ladisch.de>");
 MODULE_LICENSE("GPL");
 
@@ -208,6 +208,7 @@ static void __devexit k10temp_remove(str
 static const struct pci_device_id k10temp_id_table[] = {
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_10H_NB_MISC) },
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_11H_NB_MISC) },
+	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_CNB17H_F3) },
 	{}
 };
 MODULE_DEVICE_TABLE(pci, k10temp_id_table);

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 20+ messages in thread

* Re: [PATCH] hwmon: (k10temp) add support for AMD Family 12h/14h CPUs
  2011-02-17  8:22 ` [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD Family Clemens Ladisch
@ 2011-02-17 17:26   ` Guenter Roeck
  -1 siblings, 0 replies; 20+ messages in thread
From: Guenter Roeck @ 2011-02-17 17:26 UTC (permalink / raw)
  To: Clemens Ladisch; +Cc: Jean Delvare, lm-sensors, linux-kernel

On Thu, Feb 17, 2011 at 03:22:40AM -0500, Clemens Ladisch wrote:
> Add the PCI ID to support the internal temperature sensor of the
> AMD "Llano" and "Brazos" processor families.
> 
> Signed-off-by: Clemens Ladisch <clemens@ladisch.de>

Applied, thanks.

Since it meets the requirements for a stable patch, I applied it to the
patch list for 2.6.38 and added Cc: stable@kernel.org.

Guenter

^ permalink raw reply	[flat|nested] 20+ messages in thread

* Re: [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD
@ 2011-02-17 17:26   ` Guenter Roeck
  0 siblings, 0 replies; 20+ messages in thread
From: Guenter Roeck @ 2011-02-17 17:26 UTC (permalink / raw)
  To: Clemens Ladisch; +Cc: Jean Delvare, lm-sensors, linux-kernel

On Thu, Feb 17, 2011 at 03:22:40AM -0500, Clemens Ladisch wrote:
> Add the PCI ID to support the internal temperature sensor of the
> AMD "Llano" and "Brazos" processor families.
> 
> Signed-off-by: Clemens Ladisch <clemens@ladisch.de>

Applied, thanks.

Since it meets the requirements for a stable patch, I applied it to the
patch list for 2.6.38 and added Cc: stable@kernel.org.

Guenter

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 20+ messages in thread

* Re: [PATCH] hwmon: (k10temp) add support for AMD Family 12h/14h  CPUs
  2011-02-17 17:26   ` [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD Guenter Roeck
@ 2011-02-17 18:08     ` Jean Delvare
  -1 siblings, 0 replies; 20+ messages in thread
From: Jean Delvare @ 2011-02-17 18:08 UTC (permalink / raw)
  To: Guenter Roeck; +Cc: Clemens Ladisch, lm-sensors, linux-kernel
@@ -1,5 +1,5 @@
 /*
- * k10temp.c - AMD Family 10h/11h processor hardware monitoring
+ * k10temp.c - AMD Family 10h/11h/12h/14h processor hardware monitoring
  *
  * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>

On Thu, 17 Feb 2011 09:26:39 -0800, Guenter Roeck wrote:
> On Thu, Feb 17, 2011 at 03:22:40AM -0500, Clemens Ladisch wrote:
> > Add the PCI ID to support the internal temperature sensor of the
> > AMD "Llano" and "Brazos" processor families.
> > 
> > Signed-off-by: Clemens Ladisch <clemens@ladisch.de>
> 
> Applied, thanks.
> 
> Since it meets the requirements for a stable patch, I applied it to the
> patch list for 2.6.38 and added Cc: stable@kernel.org.

Can we have a sensors-detect patch too?

Thanks,
diff --git a/drivers/hwmon/k10temp.c b/drivers/hwmon/k10temp.c
index e3b037c..e633856 100644
--- a/drivers/hwmon/k10temp.c
+++ b/drivers/hwmon/k10temp.c
@@ -1,5 +1,5 @@
 /*
  * k10temp.c - AMD Family 10h/11h/12h/14h/15h processor hardware monitoring
  *
  * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>
  *
@@ -211,6 +211,7 @@ static DEFINE_PCI_DEVICE_TABLE(k10temp_id_table) = {
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_CNB17H_F3) },
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_15H_NB_F3) },
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_15H_M10H_F3) },
+	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_16H_NB_F3) },
 	{}
 };
 MODULE_DEVICE_TABLE(pci, k10temp_id_table);
@@ -1,5 +1,5 @@
 /*
- * k10temp.c - AMD Family 10h/11h/12h/14h/15h processor hardware monitoring
+ * k10temp.c - AMD Family 10h/11h/12h/14h/15h/16h processor hardware monitoring
  *
  * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>
diff --git a/drivers/hwmon/k10temp.c b/drivers/hwmon/k10temp.c
index e3b037c..e633856 100644
--- a/drivers/hwmon/k10temp.c
+++ b/drivers/hwmon/k10temp.c
@@ -1,5 +1,5 @@
 /*
  * k10temp.c - AMD Family 10h/11h/12h/14h/15h processor hardware monitoring
  *
  * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>
  *
@@ -211,6 +211,7 @@ static DEFINE_PCI_DEVICE_TABLE(k10temp_id_table) = {
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_CNB17H_F3) },
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_15H_NB_F3) },
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_15H_M10H_F3) },
+	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_16H_NB_F3) },
 	{}
 };
 MODULE_DEVICE_TABLE(pci, k10temp_id_table);
@@ -1,5 +1,5 @@
 /*
- * k10temp.c - AMD Family 10h/11h/12h/14h/15h processor hardware monitoring
+ * k10temp.c - AMD Family 10h/11h/12h/14h/15h/16h processor hardware monitoring
  *
  * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>
diff --git a/drivers/hwmon/k10temp.c b/drivers/hwmon/k10temp.c
index e3b037c..e633856 100644
--- a/drivers/hwmon/k10temp.c
+++ b/drivers/hwmon/k10temp.c
@@ -1,5 +1,5 @@
 /*
  * k10temp.c - AMD Family 10h/11h/12h/14h/15h processor hardware monitoring
  *
  * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>
  *
@@ -211,6 +211,7 @@ static DEFINE_PCI_DEVICE_TABLE(k10temp_id_table) = {
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_CNB17H_F3) },
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_15H_NB_F3) },
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_15H_M10H_F3) },
+	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_16H_NB_F3) },
 	{}
 };
 MODULE_DEVICE_TABLE(pci, k10temp_id_table);
@@ -1,5 +1,5 @@
 /*
- * k10temp.c - AMD Family 10h/11h/12h/14h/15h processor hardware monitoring
+ * k10temp.c - AMD Family 10h/11h/12h/14h/15h/16h processor hardware monitoring
  *
  * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>
diff --git a/drivers/hwmon/k10temp.c b/drivers/hwmon/k10temp.c
index e3b037c..e633856 100644
--- a/drivers/hwmon/k10temp.c
+++ b/drivers/hwmon/k10temp.c
@@ -1,5 +1,5 @@
 /*
  * k10temp.c - AMD Family 10h/11h/12h/14h/15h processor hardware monitoring
  *
  * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>
  *
@@ -211,6 +211,7 @@ static DEFINE_PCI_DEVICE_TABLE(k10temp_id_table) = {
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_CNB17H_F3) },
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_15H_NB_F3) },
 	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_15H_M10H_F3) },
+	{ PCI_VDEVICE(AMD, PCI_DEVICE_ID_AMD_16H_NB_F3) },
 	{}
 };
 MODULE_DEVICE_TABLE(pci, k10temp_id_table);
@@ -1,5 +1,5 @@
 /*
- * k10temp.c - AMD Family 10h/11h/12h/14h/15h processor hardware monitoring
+ * k10temp.c - AMD Family 10h/11h/12h/14h/15h/16h processor hardware monitoring
  *
  * Copyright (c) 2009 Clemens Ladisch <clemens@ladisch.de>
-- 
1.7.4.4


_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply related	[flat|nested] 20+ messages in thread

* Re: [lm-sensors] [PATCH] hwmon: (k10temp) Add support for Fam16h (Kabini)
  2013-08-23 20:14     ` [lm-sensors] " Wei Hu
@ 2013-08-23 20:47       ` Guenter Roeck
  -1 siblings, 0 replies; 20+ messages in thread
From: Guenter Roeck @ 2013-08-23 20:47 UTC (permalink / raw)
  To: Wei Hu; +Cc: Guenter Roeck, Clemens Ladisch, lm-sensors, linux-kernel

On Fri, Aug 23, 2013 at 01:14:03PM -0700, Wei Hu wrote:
> The temperature reporting interface stays the same, so we just
> add the PCI-ID to the list.
> 
> Verified on AMD Olive Hill.
> 
> Signed-off-by: Wei Hu <wei@aristanetworks.com>

Applied to -next.

I marked it for inclusion in stable-3.10, so it will ultimately find
its way there. It does not apply cleanly to earlier stable releases.
If is needed in any of those, someone will have to back-port it after
it is available in mainline.

Thanks,
Guenter

^ permalink raw reply	[flat|nested] 20+ messages in thread

* Re: [lm-sensors] [PATCH] hwmon: (k10temp) Add support for Fam16h (Kabini)
@ 2013-08-23 20:47       ` Guenter Roeck
  0 siblings, 0 replies; 20+ messages in thread
From: Guenter Roeck @ 2013-08-23 20:47 UTC (permalink / raw)
  To: Wei Hu; +Cc: Guenter Roeck, Clemens Ladisch, lm-sensors, linux-kernel

On Fri, Aug 23, 2013 at 01:14:03PM -0700, Wei Hu wrote:
> The temperature reporting interface stays the same, so we just
> add the PCI-ID to the list.
> 
> Verified on AMD Olive Hill.
> 
> Signed-off-by: Wei Hu <wei@aristanetworks.com>

Applied to -next.

I marked it for inclusion in stable-3.10, so it will ultimately find
its way there. It does not apply cleanly to earlier stable releases.
If is needed in any of those, someone will have to back-port it after
it is available in mainline.

Thanks,
Guenter

_______________________________________________
lm-sensors mailing list
lm-sensors@lm-sensors.org
http://lists.lm-sensors.org/mailman/listinfo/lm-sensors

^ permalink raw reply	[flat|nested] 20+ messages in thread

end of thread, other threads:[~2013-08-23 20:47 UTC | newest]

Thread overview: 20+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2013-08-23 17:38 [PATCH] hwmon: (k10temp) Add support for Fam16h (Kabini) Wei Hu
2013-08-23 17:38 ` [lm-sensors] " Wei Hu
2013-08-23 18:25 ` Clemens Ladisch
2013-08-23 18:25   ` [lm-sensors] " Clemens Ladisch
2013-08-23 19:58 ` Guenter Roeck
2013-08-23 19:58   ` Guenter Roeck
2013-08-23 20:14   ` Wei Hu
2013-08-23 20:14     ` [lm-sensors] " Wei Hu
2013-08-23 20:47     ` Guenter Roeck
2013-08-23 20:47       ` Guenter Roeck
  -- strict thread matches above, loose matches on Subject: below --
2011-02-17  8:22 [PATCH] hwmon: (k10temp) add support for AMD Family 12h/14h CPUs Clemens Ladisch
2011-02-17  8:22 ` [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD Family Clemens Ladisch
2011-02-17 17:26 ` [PATCH] hwmon: (k10temp) add support for AMD Family 12h/14h CPUs Guenter Roeck
2011-02-17 17:26   ` [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD Guenter Roeck
2011-02-17 18:08   ` [PATCH] hwmon: (k10temp) add support for AMD Family 12h/14h CPUs Jean Delvare
2011-02-17 18:08     ` [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD Jean Delvare
2011-02-17 18:39     ` [PATCH] hwmon: (k10temp) add support for AMD Family 12h/14h CPUs Guenter Roeck
2011-02-17 18:39       ` [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD Guenter Roeck
2011-02-17 19:23       ` [PATCH] hwmon: (k10temp) add support for AMD Family 12h/14h CPUs Jean Delvare
2011-02-17 19:23         ` [lm-sensors] [PATCH] hwmon: (k10temp) add support for AMD Jean Delvare

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.